@@ -9,6 +9,7 @@ mod component;
 mod created_node;
 mod dispatch;
 mod dom_updater;
+mod effects;
 pub mod events;
 mod http;
 mod program;
@@ -17,10 +18,11 @@ mod window;
 
 pub use application::{Application, Measurements};
 pub use callback::Callback;
-pub use component::{Component, Container, Effects, View};
+pub use component::{Component, Container, View};
 pub use created_node::CreatedNode;
 pub use dispatch::Dispatch;
 pub use dom_updater::DomUpdater;
+pub use effects::Effects;
 pub use events::*;
 pub use http::Http;
 pub use program::Program;
