@@ -19,8 +19,8 @@ pub const SVG_NAMESPACE: &str = "http://www.w3.org/2000/svg";
 ///
 pub fn svg_element<MSG>(
     tag: &'static str,
-    attrs: Vec<crate::Attribute<MSG>>,
-    children: Vec<crate::Node<MSG>>,
+    attrs: impl IntoIterator<Item = crate::Attribute<MSG>>,
+    children: impl IntoIterator<Item = crate::Node<MSG>>,
 ) -> crate::Node<MSG> {
     crate::html::html_element_ns(tag, SVG_NAMESPACE, attrs, children)
 }
